import { M as MastraBase } from '../base-5mVaiPUb.js';
import * as ai from 'ai';
import '@opentelemetry/api';
import '../index-B2JCcAQt.js';
import 'pino';
import 'stream';
import '@opentelemetry/sdk-node';
import '@opentelemetry/sdk-trace-base';

declare const defaultEmbedder: (modelId: string) => ai.EmbeddingModel<string>;

interface QueryResult {
    id: string;
    score: number;
    metadata?: Record<string, any>;
    vector?: number[];
}
interface IndexStats {
    dimension: number;
    count: number;
    metric?: 'cosine' | 'euclidean' | 'dotproduct';
}
declare abstract class MastraVector extends MastraBase {
    constructor();
    abstract upsert(indexName: string, vectors: number[][], metadata?: Record<string, any>[], ids?: string[]): Promise<string[]>;
    abstract createIndex(indexName: string, dimension: number, metric?: 'cosine' | 'euclidean' | 'dotproduct'): Promise<void>;
    abstract query(indexName: string, queryVector: number[], topK?: number, filter?: Record<string, any>, includeVector?: boolean): Promise<QueryResult[]>;
    abstract listIndexes(): Promise<string[]>;
    abstract describeIndex(indexName: string): Promise<IndexStats>;
    abstract deleteIndex(indexName: string): Promise<void>;
}

export { type IndexStats, MastraVector, type QueryResult, defaultEmbedder };
